==> handy-storage-1.0.0.tgz: package/lib/index.js <==
'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var fs = require('fs');
var beautify = require('json-beautify');

var HandyStorage = function () {

    /**
     * Handy Storage constructor function
     * @param {string | object} path - Path of JSON file | Options objects including {path, autoSave}
     * @param {boolean} autoSave
     */
    function HandyStorage(path) {
        var autoSave = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

        _classCallCheck(this, HandyStorage);

        if ((typeof path === 'undefined' ? 'undefined' : _typeof(path)) === 'object') {
            if (path.autoSave !== undefined) autoSave = path.autoSave;
            path = path.path || path.url || undefined;
        }
        if (path !== undefined) this.load(path);
        this.autoSave = autoSave;
    }

    /**
     * Select and loads a JSON file
     * @param {string} path - Path of JSON file you want to load
     */


    _createClass(HandyStorage, [{
        key: 'load',
        value: function load(path) {
            this.path = path;
            var content = fs.readFileSync(path, 'utf8');
            this.data = JSON.parse(content == '' ? '{}' : content);
        }

        /**
         * Saves the current storage into the selected JSON file
         */

    }, {
        key: 'save',
        value: function save() {
            var _this = this;

            return new Promise(function (resolve, reject) {
                fs.writeFile(_this.path, beautify(_this.data, null, 4, 50), function (err) {
                    if (err) return reject(err);
                    resolve();
                });
            });
        }

        /**
         * autoSave variable setter
         * @param (boolean) mustAutoSave
         */

    }, {
        key: 'autoSave',
        set: function set(mustAutoSave) {
            if (typeof mustAutoSave === 'boolean') {
                this._autoSave = mustAutoSave;
                if (mustAutoSave) {} else {}
            }
        }

        /**
         * autoSave variable getter
         */
        ,
        get: function get() {
            return this._autoSave;
        }
    }]);

    return HandyStorage;
}();

module.exports = HandyStorage;

==> handy-storage-1.2.1.tgz: package/lib/index.js <==
'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var fs = require('fs');
var beautify = require('json-beautify');

var HandyStorage = function () {

    /**
     * Represents a "Handy" storage
     * @constructor
     * @param {String} [path] - Path of JSON file
     */
    function HandyStorage(path) {
        _classCallCheck(this, HandyStorage);

        // Initial variables
        this.savingInProgress = false;

        // If path was initialized load it immediately 
        if (path !== undefined) {
            this.load(path);
        }
    }

    /**
     * Loads a JSON file
     * @param {string} path - Path of JSON file
     */


    _createClass(HandyStorage, [{
        key: 'load',
        value: function load(path) {
            this.path = path;
            var content = fs.readFileSync(path, 'utf8');
            this.data = JSON.parse(content == '' ? '{}' : content);
        }

        /**
         * Saves current data into the JSON file
         * @return {Promise} Saving data callback promise
         */

    }, {
        key: 'save',
        value: function save() {
            var _this = this;

            return new Promise(function (resolve, reject) {
                // Reject if saving is in progress
                if (_this.savingInProgress) return reject();

                // Save it if saving was not in progress
                _this.savingInProgress = true;

                // fileData
                var fileData = beautify(_this.data, null, 4, 50);

                // writing fileData to file
                fs.writeFile(_this.path, fileData, { flag: 'w' }, function (err) {
                    _this.savingInProgress = false;
                    if (err) return reject(err);
                    resolve(_this.data);
                });
            });
        }
    }]);

    return HandyStorage;
}();

module.exports = HandyStorage;
